==> mcss-0.0.31.tar.gz: mcss-0.0.31/test/dsmts/test-simulation-batch.two-vars.R <==
testmodel<-function(model,n,tspath=".",
     verb=TRUE,plot=FALSE,meanthresh=3,sdthresh=5)
{
      stem=paste(tspath,model,sep="/")
      modelfile=paste(stem,".mcss.params",sep="")
      resultsfile=paste(stem,".mcss.h5",sep="")
      meanfile=paste(stem,"-mean.csv",sep="")
      sdfile=paste(stem,"-sd.csv",sep="")
      graphfile=paste(stem,".mcss.pdf",sep="")
      meantab=read.csv(meanfile,header=TRUE)
      if (plot==TRUE) {
	      pdf(file=graphfile);
	      legendnames=colnames(meantab[2:NCOL(meantab)])
	  }
      meantab=meantab[,2:ncol(meantab)]
      sdtab=read.csv(sdfile,header=TRUE)
      sdtab=sdtab[,2:ncol(sdtab)]
      xbartab=meantab
      stab=sdtab
      xbartab[]=0
      stab[]=0
      for (i in 1:n) {
              if (verb==TRUE)
                      print(i)
              runcmd=paste("mcss ",modelfile)
              system(runcmd)
              runcmd=paste("mcss-postprocess -S 1,0 -l ",resultsfile,
                     " > run.out")
              system(runcmd)
              outtab=read.table("run.out",
                      header=TRUE)
              outtab=outtab[,2:ncol(outtab)]
              xbartab=xbartab+outtab
              stab=stab+(outtab-meantab)*(outtab-meantab)
      }
      xbartab=xbartab/n
      stab=stab/n
      ztab=sqrt(n)*(xbartab-meantab)/sdtab
      ytab=sqrt(n/2)*((stab/(sdtab*sdtab))-1)
      ztab=as.matrix(ztab)
      ytab=as.matrix(ytab)
      meanfails=sum(abs(xbartab-meantab)>
                meanthresh*sdtab/sqrt(n))
      sdfails=sum((ytab>sdthresh)|
                (ytab<(-sdthresh)),na.rm=TRUE)
      if (verb==TRUE) {
              print(ztab)
              print(ytab)
      }
      if (plot==TRUE) {
             op=par(mfrow=c(2,1))
             plot(0,0,xlim=c(0,50), ylim=c(-10,10),
             xlab="Time", ylab="SDs from truth")
             title(main=paste("Mean diagnostics for model", model))
             abline(0,0,col="green")
             abline(meanthresh,0,col="red")
             abline(-meanthresh,0,col="red")
             for (i in 1:ncol(ztab))
                     lines(ts(ztab[,i],start=0),lwd=3)
             plot(0,0,xlim=c(0,50),ylim=c(-10,10),xlab="Time",ylab="SDs from truth")
             title(main=paste("SD diagnostics for model",model))
             abline(0,0,col="green")
             abline(sdthresh,0,col="red")
             abline(-sdthresh,0,col="red")
             for (i in 1:ncol(ztab))
                     lines(ts(ytab[,i],start=0),lwd=3)
             par(op)
             plot(0,0,type="n",xlim=c(0,50),ylim=c(min(xbartab),max(xbartab)),xlab="time",ylab="mean")
             if(NCOL(xbartab) == 1) {
		         lines(x=0:50,y=meantab,lty=1,lwd=0.5,col="red")
	    	     lines(x=0:50,y=xbartab,lty=1,col="black")
             } else {
	             for (i in 1:NCOL(xbartab)) {
		             lines(x=0:50,y=meantab[,i],lty=1,lwd=0.5,col="red")
	    	         lines(x=0:50,y=xbartab[,i],lty=i,col="black")
	        	 }
	       	 }
             legend(15,max(xbartab),legendnames,lty=1:NCOL(xbartab))
             plot(0,0,type="n",xlim=c(0,50),ylim=c(min(sqrt(stab)),max(sqrt(stab))),xlab="time",ylab="standard deviation")
             if(NCOL(stab) == 1) {
		         lines(x=0:50,y=sdtab,lty=1,lwd=0.5,col="red")
	    	     lines(x=0:50,y=sqrt(stab),lty=1,col="black")
             } else {
	             for (i in 1:NCOL(stab)) {
		             lines(x=0:50,y=sdtab[,i],lty=1,lwd=0.5,col="red")
	    	         lines(x=0:50,y=sqrt(stab[,i]),lty=i,col="black")
	        	 }
	       	 }
             legend(15,max(sqrt(stab)),legendnames,lty=1:NCOL(stab))
      }
      print(model)
      print(paste(n,"runs"))
      print(paste(meanfails,"mean test fails"))
      print(paste(sdfails,"sd test fails"))
}

==> mcss-1.0.1.tar.gz: mcss-1.0.1/test/dsmts/test-simulation-batch.two-vars.R <==
testmodel<-function(model,n,tspath=".",
     verb=TRUE,plot=FALSE,meanthresh=3,sdthresh=5,simalg="")
{
      stem=paste(tspath,model,sep="/")
      modelfile=paste(stem,".mcss.params",sep="")
      resultsfile=paste(stem,".mcss.h5",sep="")
      meanfile=paste(stem,"-mean.csv",sep="")
      sdfile=paste(stem,"-sd.csv",sep="")
      graphfile=paste(stem,".mcss.pdf",sep="")
      meantab=read.csv(meanfile,header=TRUE)
      if (plot==TRUE) {
	      pdf(file=graphfile);
	      legendnames=colnames(meantab[2:NCOL(meantab)])
	  }
      meantab=meantab[,2:ncol(meantab)]
      sdtab=read.csv(sdfile,header=TRUE)
      sdtab=sdtab[,2:ncol(sdtab)]
      xbartab=meantab
      stab=sdtab
      xbartab[]=0
      stab[]=0
      for (i in 1:n) {
              if (verb==TRUE)
                      print(i)
              if (simalg=="")
                      runcmd=paste("mcss ",modelfile,sep="")
              else
                      runcmd=paste("mcss ",modelfile," simulation_algorithm=",simalg,sep="")
              system(runcmd)
              runcmd=paste("mcss-postprocess -S 1,0 -l ",resultsfile,
                     " > run.out")
              system(runcmd)
              outtab=read.table("run.out",
                      header=TRUE)
              outtab=outtab[,2:ncol(outtab)]
              xbartab=xbartab+outtab
              stab=stab+(outtab-meantab)*(outtab-meantab)
      }
      xbartab=xbartab/n
      stab=stab/n
      ztab=sqrt(n)*(xbartab-meantab)/sdtab
      ytab=sqrt(n/2)*((stab/(sdtab*sdtab))-1)
      ztab=as.matrix(ztab)
      ytab=as.matrix(ytab)
      meanfails=sum(abs(xbartab-meantab)>
                meanthresh*sdtab/sqrt(n))
      sdfails=sum((ytab>sdthresh)|
                (ytab<(-sdthresh)),na.rm=TRUE)
      if (verb==TRUE) {
              print(ztab)
              print(ytab)
      }
      if (plot==TRUE) {
             op=par(mfrow=c(2,1))
             plot(0,0,xlim=c(0,50), ylim=c(-10,10),
             xlab="Time", ylab="SDs from truth")
             title(main=paste("Mean diagnostics for model", model))
             abline(0,0,col="green")
             abline(meanthresh,0,col="red")
             abline(-meanthresh,0,col="red")
             for (i in 1:ncol(ztab))
                     lines(ts(ztab[,i],start=0),lwd=3)
             plot(0,0,xlim=c(0,50),ylim=c(-10,10),xlab="Time",ylab="SDs from truth")
             title(main=paste("SD diagnostics for model",model))
             abline(0,0,col="green")
             abline(sdthresh,0,col="red")
             abline(-sdthresh,0,col="red")
             for (i in 1:ncol(ztab))
                     lines(ts(ytab[,i],start=0),lwd=3)
             par(op)
             plot(0,0,type="n",xlim=c(0,50),ylim=c(min(xbartab),max(xbartab)),xlab="time",ylab="mean")
             if(NCOL(xbartab) == 1) {
		         lines(x=0:50,y=meantab,lty=1,lwd=0.5,col="red")
	    	     lines(x=0:50,y=xbartab,lty=1,col="black")
             } else {
	             for (i in 1:NCOL(xbartab)) {
		             lines(x=0:50,y=meantab[,i],lty=1,lwd=0.5,col="red")
	    	         lines(x=0:50,y=xbartab[,i],lty=i,col="black")
	        	 }
	       	 }
             legend(15,max(xbartab),legendnames,lty=1:NCOL(xbartab))
             plot(0,0,type="n",xlim=c(0,50),ylim=c(min(sqrt(stab)),max(sqrt(stab))),xlab="time",ylab="standard deviation")
             if(NCOL(stab) == 1) {
		         lines(x=0:50,y=sdtab,lty=1,lwd=0.5,col="red")
	    	     lines(x=0:50,y=sqrt(stab),lty=1,col="black")
             } else {
	             for (i in 1:NCOL(stab)) {
		             lines(x=0:50,y=sdtab[,i],lty=1,lwd=0.5,col="red")
	    	         lines(x=0:50,y=sqrt(stab[,i]),lty=i,col="black")
	        	 }
	       	 }
             legend(15,max(sqrt(stab)),legendnames,lty=1:NCOL(stab))
      }
      print(model)
      print(paste(n,"runs"))
      print(paste(meanfails,"mean test fails"))
      print(paste(sdfails,"sd test fails"))
}
